import os
import pandas as pd
from collections import Counter
import seaborn as sns
import matplotlib.pyplot as plt


def read_go(go_annotation_file):
    df = pd.read_csv(go_annotation_file, delimiter = "\t")
    df = df[df['enrichment'] == 'e'][['name', 'name_space', 'p_val']]
    
    df2 = pd.DataFrame(columns=["name", "name_space", "p_val"]) 
    for name_space in ['biological_process', 'molecular_function', 'cellular_component']:
        df_ = df[df['name_space'] == name_space]
        df_ = df_.sort_values(by='p_val')
        if df_.shape[0] > 10:
            df_ = df_.iloc[0:10]
        df2 = df2.append(df_)
    return df2
   

df = pd.DataFrame(columns=["name", "name_space", "p_val"])    
for go_annotation_file in os.listdir('network_go_annotation'):
    single_df = read_go('network_go_annotation/' + go_annotation_file)
    df = df.append(single_df)

df_plot = pd.DataFrame(columns=['name', 'counts', 'name_space']) 
for name_space in ['biological_process', 'molecular_function', 'cellular_component']:
    counter = Counter(df[df["name_space"] == name_space]["name"])
    df_ = pd.DataFrame.from_dict(counter, orient='index').reset_index()
    df_.columns = ['name', 'counts']
    df_ = df_.sort_values(by='counts', ascending=False)
    if df_.shape[0] > 10:
        df_ = df_.iloc[0:10]
    df_['name_space'] = name_space
    df_plot = df_plot.append(df_)
 

fig, ax = plt.subplots()
fig.set_size_inches(8, 8)
sns_plot = sns.barplot(x="counts", y="name", hue = "name_space", data=df_plot) 
ax.set(ylabel="", xlabel="counts (top 10)")
sns.despine(left=True, bottom=True)  
plt.savefig('go_annotation_counts.pdf', format='pdf', bbox_inches = 'tight')
